/* diajava.cc 13/08/2001 21.16.30 */
PUBLIC UISTATE::UISTATE (void);
PUBLIC DIAJAVA::DIAJAVA (bool guiok);
PUBLIC DIAJAVA::DIAJAVA (int handlein,
	 int handleout,
	 const char *lines);
PUBLIC DIAJAVA::~DIAJAVA (void);
PUBLIC int DIAJAVA::is_ok (void);
PUBLIC ITEM_VAL::ITEM_VAL (const char *_diapath,
	 const char *_id,
	 const char *_val);
PUBLIC ITEM_VAL *ITEM_VALS::getitem (int no);
PUBLIC const char *ITEM_VALS::getval (const char *diapath,
	 const char *id);
PUBLIC int ITEM_VALS::getvals (const char *diapath,
	 const char *id,
	 SSTRINGS&tb);
PUBLIC const char *DIAJAVA::getval (const char *diapath,
	 const char *id);
PUBLIC int DIAJAVA::getvals (const char *diapath,
	 const char *id,
	 SSTRINGS&tb);
PUBLIC int DIAJAVA::wait (POPENWAITS&tbpopen,
	 char dianame[200],
	 char actionid[100],
	 char menubarid[100],
	 int &menu,
	 int &but);
PUBLIC void DIAJAVA::send (const char *ctl, ...);
PUBLIC void DIAJAVA::sendcmd (int cmd, const char *ctl, ...);
PUBLIC void DIAJAVA::flush (void);
/* _dict.cc 31/03/1998 10.44.48 */
/* guidump.cc 12/04/1998 08.06.28 */
/* guispy.cc 07/01/1998 00.04.42 */
